# vizdxp

## Simple Exploratory Data Analysis web application

vizdxp is an open-source web app designed via streamlit weaved with plotly library. **Its incredibly simple - Just drag & drop any csv and explore the data visually.** By default the application will figure out better visualization based on user selections. Feel free to customize as needed.

## Keys
- **Simple** and quick for any **Exploratory Data Analysis**
- Create interactive **Dashboard web app within minutes** from any csv and share the findings
- **Deploy** it as a web application in your own workstations too
- By **Default** - chart types and aggregations are applied based on columns selected by user, null rows are removed, date fields are converted to multiple subfields
- Highly **Customizable**
- No more static reports
- Chart types included - Scatter, Bar, Pie, Heatmap, Histogram and Box plots

## Installation

pip install vizdxp

Run: python -m vizdxp

Explore vizdxp through a browser. Once installation is complete, user can work totally offline.

## Blog

Wrriten a blog on vizdxp [here](https://medium.com/analytics-vidhya/introducing-vizdxp-for-quick-exploratory-data-analysis-and-visualizations-89128326e8ac)

## License
- vizdxp is completely free, open sourced and licensed under MIT license.
- Vizdxp is developed with Streamlit as the framework. Further details on [streamlit](https://www.streamlit.io/)
- Plotly is the visualization library used. Further details on [plotly](https://plotly.com/)
